==> karajan-0.4.0.tar.gz: karajan-0.4.0/setup.py <==
#
# Copyright 2017 Wooga GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
# of the Software, and to permit persons to whom the Software is furnished to do
# so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from setuptools import setup

__version__ = '0.4.0'

setup(
    name='karajan',
    version=__version__,
    url='https://github.com/wooga/karajan',
    license='',
    packages=['karajan', 'karajan.bin'],
    author='Cedrik Neumann',
    author_email='cedrik.neumann@outlook.com',
    description='A conductor of aggregations in Apache Airflow',
    scripts=['karajan/bin/karajan'],
    install_requires=[
        "pyyaml",
        "apache-airflow[jdbc]~=1.8",
    ],
    extras_require={
        'dev': [
            'behave',
            'nose',
            'nose-timer',
            'rednose',
            'coverage',
            'parameterized',
            'mock',
            'pylint',
            'autopep8',
            'python-semantic-release',
        ],
    },
)

==> karajan-0.4.1.tar.gz: karajan-0.4.1/setup.py <==
#
# Copyright 2017 Wooga GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
# of the Software, and to permit persons to whom the Software is furnished to do
# so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from setuptools import setup

__version__ = '0.4.1'

setup(
    name='karajan',
    version=__version__,
    url='https://github.com/m1racoli/karajan',
    license='',
    packages=['karajan', 'karajan.bin'],
    author='Cedrik Neumann',
    author_email='cedrik.neumann@outlook.com',
    description='A conductor of aggregations in Apache Airflow',
    scripts=['karajan/bin/karajan'],
    install_requires=[
        "pyyaml",
        "apache-airflow[jdbc]~=1.8",
    ],
    extras_require={
        'dev': [
            'behave',
            'nose',
            'nose-timer',
            'rednose',
            'coverage',
            'parameterized',
            'mock',
            'pylint',
            'autopep8',
            'python-semantic-release',
        ],
    },
)
